<?php
session_start();
include 'license_check.php';
include 'db_connect.php';

// Überprüfung, ob der Benutzer angemeldet ist
if (!isset($_SESSION['user_id'])) {
    header('Location: login.php');
    exit();
}

$mitarbeiter_id = $_SESSION['user_id'];
$errors = [];
$message = "";

// Ebenen aus der Datenbank laden
$stmt = $pdo->prepare('SELECT value FROM settings WHERE key_name = "lagerplatz_ebenen" LIMIT 1');
$stmt->execute();
$ebenenSetting = $stmt->fetch();
$verfuegbare_ebenen = $ebenenSetting ? json_decode($ebenenSetting['value'], true) : [];



// Verarbeitung der Formulareingabe
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    if (isset($_POST['action'])) {
        $action = $_POST['action']; // 'start', 'weiter', 'zurueck', 'ueberspringen', 'abbrechen', 'cancel_over_capacity', 'updateDatabase'

        if ($action === 'start') {
            // Verarbeiten der Ebenenauswahl
            if (isset($_POST['ebenen'])) {
                $ausgewaehlte_ebenen = $_POST['ebenen'];

                if (in_array('Alles', $ausgewaehlte_ebenen)) {
                    // Wähle alle Kürzel
                    $ausgewaehlte_ebenen = array_column($verfuegbare_ebenen, 'kurzel');
                }
                if (empty($ausgewaehlte_ebenen)) {
                    $errors[] = "Bitte wählen Sie mindestens eine Ebene aus.";
                } else {
                    // Initialisierung: Einträge für die ausgewählten Ebenen erstellen
                    $stmt = $pdo->prepare('SELECT id, name FROM lagerplaetze ORDER BY id ASC');
                    $stmt->execute();
                    $lagerplaetze = $stmt->fetchAll(PDO::FETCH_ASSOC);

                    $stmtInsert = $pdo->prepare('INSERT INTO inventur_progress (mitarbeiter_id, lagerplatz_id) VALUES (?, ?)');

                    foreach ($lagerplaetze as $lagerplatz) {
                        // Ebene aus dem Namen extrahieren
                        $ebene = strtoupper(substr($lagerplatz['name'], 0, 2));
                        
                        // Für "GH"-Format (z.B. "14/01/01")
                        if (preg_match('/^[0-9]{2}\/[0-9]{2}\/[0-9]{2}$/', $lagerplatz['name'])) {
                            $ebene = 'GH';
                        }

                        if (in_array($ebene, $ausgewaehlte_ebenen)) {
                            // Prüfen, ob bereits ein Eintrag existiert
                            $stmtCheck = $pdo->prepare('SELECT COUNT(*) FROM inventur_progress WHERE mitarbeiter_id = ? AND lagerplatz_id = ?');
                            $stmtCheck->execute([$mitarbeiter_id, $lagerplatz['id']]);
                            $exists = $stmtCheck->fetchColumn() > 0;

                            if (!$exists) {
                                // Eintrag hinzufügen
                                $stmtInsert->execute([$mitarbeiter_id, $lagerplatz['id']]);
                            }
                        }
                    }

                    header('Location: inventur.php');
                    exit();
                }
            } else {
                $errors[] = "Keine Ebenen ausgewählt.";
            }
        } elseif ($action === 'updateDatabase') {
            // Beginne eine Transaktion
            $pdo->beginTransaction();

            try {
                // Hole alle abgeschlossenen und übersprungenen Einträge
                $stmt = $pdo->prepare('SELECT lagerplatz_id, belegung, completed FROM inventur_progress WHERE mitarbeiter_id = ? AND completed IN (1,2)');
                $stmt->execute([$mitarbeiter_id]);
                $inventurData = $stmt->fetchAll(PDO::FETCH_ASSOC);

                foreach ($inventurData as $data) {
                    $lagerplatzId = $data['lagerplatz_id'];
                    $belegung = $data['belegung'];
                    $completed = $data['completed'];

                    if ($completed == 1) {
                        // Alten Belegungswert abrufen
                        $stmtGetOld = $pdo->prepare('SELECT belegung FROM lagerplaetze WHERE id = ?');
                        $stmtGetOld->execute([$lagerplatzId]);
                        $alterBelegung = $stmtGetOld->fetchColumn();

                        // Belegung aktualisieren
                        $stmtUpdate = $pdo->prepare('UPDATE lagerplaetze SET belegung = ? WHERE id = ?');
                        $stmtUpdate->execute([$belegung, $lagerplatzId]);

                        // In Inventurprotokoll eintragen (optional)
                        $stmtInsertLog = $pdo->prepare('INSERT INTO inventur_protokoll (lagerplatz_id, alter_belegung, neuer_belegung, mitarbeiter_id) VALUES (?, ?, ?, ?)');
                        $stmtInsertLog->execute([$lagerplatzId, $alterBelegung, $belegung, $mitarbeiter_id]);
                    } elseif ($completed == 2) {
                        // Übersprungene Einträge protokollieren
                        $stmtInsertLog = $pdo->prepare('INSERT INTO inventur_protokoll (lagerplatz_id, alter_belegung, neuer_belegung, mitarbeiter_id) VALUES (?, ?, ?, ?)');
                        $stmtInsertLog->execute([$lagerplatzId, 0, 0, $mitarbeiter_id]);
                    }

                }

                // Fortschritt aus der inventur_progress-Tabelle löschen
                $stmtDeleteProgress = $pdo->prepare('DELETE FROM inventur_progress WHERE mitarbeiter_id = ?');
                $stmtDeleteProgress->execute([$mitarbeiter_id]);

                $stmtUpdateTaskStatus = $pdo->prepare('UPDATE aufgaben SET status = ? WHERE status = ?');
                $stmtUpdateTaskStatus->execute(['abgeschlossen', 'in_bearbeitung']);

                $pdo->commit();

                $message = "Die Inventur wurde erfolgreich abgeschlossen und die Datenbank aktualisiert.";
                } catch (Exception $e) {
                    $pdo->rollBack();
                    $errors[] = "Es ist ein Fehler aufgetreten: " . htmlspecialchars($e->getMessage());
                }
        } elseif ($action === 'abbrechen') {
            // Fortschritt löschen
            $stmtDeleteProgress = $pdo->prepare('DELETE FROM inventur_progress WHERE mitarbeiter_id = ?');
            $stmtDeleteProgress->execute([$mitarbeiter_id]);

            // Status der Aufgabe auf 'offen' setzen
            $stmtUpdateTaskStatus = $pdo->prepare('UPDATE aufgaben SET status = ? WHERE status = ?');
            $stmtUpdateTaskStatus->execute(['offen', 'in_bearbeitung']);

            // Nachricht setzen
            $message = "Die Inventur wurde abgebrochen und zurückgesetzt.";

            $progressExists = false; // Fortschritt zurücksetzen
            $show_ebenen_auswahl = true; // Auswahlseite anzeigen
        } else {
            // Andere Aktionen: 'weiter', 'zurueck', 'ueberspringen', 'cancel_over_capacity'
            if (isset($_POST['lagerplatz_id'])) {
                $lagerplatz_id = (int)$_POST['lagerplatz_id'];

                if ($action === 'weiter') {
                    if (isset($_POST['belegung']) && $_POST['belegung'] !== '') {
                        $belegung = (int)$_POST['belegung'];

                        // Aktuelle Kapazität abrufen
                        $stmt = $pdo->prepare('SELECT kapazitaet FROM lagerplaetze WHERE id = ?');
                        $stmt->execute([$lagerplatz_id]);
                        $kapazitaet = $stmt->fetchColumn();

                        // Prüfen, ob die Belegung die Kapazität überschreitet
                        if ($belegung >= 0 && ($belegung <= $kapazitaet || isset($_POST['confirm_over_capacity']))) {
                            // Wenn Belegung größer als Kapazität und Bestätigung erhalten, Kapazität aktualisieren
                            if ($belegung > $kapazitaet && isset($_POST['confirm_over_capacity'])) {
                                // Kapazität aktualisieren
                                $stmtUpdateKapazitaet = $pdo->prepare('UPDATE lagerplaetze SET kapazitaet = ? WHERE id = ?');
                                $stmtUpdateKapazitaet->execute([$belegung, $lagerplatz_id]);
                                $kapazitaet = $belegung; // Lokale Variable aktualisieren
                            }

                            // Aktualisierung der Inventurprogress-Tabelle
                            $stmtUpdate = $pdo->prepare('UPDATE inventur_progress SET belegung = ?, completed = 1 WHERE mitarbeiter_id = ? AND lagerplatz_id = ?');
                            $stmtUpdate->execute([$belegung, $mitarbeiter_id, $lagerplatz_id]);

                            // Belegung zurücksetzen für den nächsten Lagerplatz
                            $belegung = null;
                        } else {
                            if ($belegung > $kapazitaet) {
                                // Belegung überschreitet Kapazität, Bestätigung erforderlich
                                $overCapacity = true;
                                $retainBelegungValue = true;
                            } else {
                                $errors[] = "Die Belegung für Lagerplatz ID " . htmlspecialchars($lagerplatz_id) . " muss größer oder gleich 0 sein.";
                                $retainBelegungValue = true;
                            }
                        }
                    } else {
                        $errors[] = "Bitte geben Sie eine Belegung ein.";
                        $retainBelegungValue = true;
                    }
                } elseif ($action === 'zurueck') {
                    // Setze den aktuellen Lagerplatz zurück auf pending
                    $stmtUpdateCurrent = $pdo->prepare('UPDATE inventur_progress SET completed = 0 WHERE mitarbeiter_id = ? AND lagerplatz_id = ?');
                    $stmtUpdateCurrent->execute([$mitarbeiter_id, $lagerplatz_id]);

                    // Finde den vorherigen Lagerplatz
                    $stmtPrev = $pdo->prepare('
                        SELECT lp.id
                        FROM lagerplaetze lp
                        JOIN inventur_progress ip ON lp.id = ip.lagerplatz_id
                        WHERE ip.mitarbeiter_id = ? AND lp.id < ? 
                        ORDER BY lp.id DESC
                        LIMIT 1
                    ');
                    $stmtPrev->execute([$mitarbeiter_id, $lagerplatz_id]);
                    $prevLagerplatz = $stmtPrev->fetch(PDO::FETCH_ASSOC);

                    if ($prevLagerplatz) {
                        $currentLagerplatzId = $prevLagerplatz['id'];
                    } else {
                        $errors[] = "Kein vorheriger Lagerplatz vorhanden.";
                    }
                } elseif ($action === 'ueberspringen') {
                    // Setze den aktuellen Lagerplatz auf übersprungen
                    $stmtUpdate = $pdo->prepare('UPDATE inventur_progress SET belegung = NULL, completed = 2 WHERE mitarbeiter_id = ? AND lagerplatz_id = ?');
                    $stmtUpdate->execute([$mitarbeiter_id, $lagerplatz_id]);
                } elseif ($action === 'cancel_over_capacity') {
                    // Benutzer hat Überkapazität nicht bestätigt
                    $errors[] = "Bitte passen Sie die Belegung an, sie darf die Kapazität nicht überschreiten.";
                    $retainBelegungValue = true;
                }
            }
        }
    }
}

// Überprüfung, ob der Benutzer bereits einen Fortschritt hat
// Überprüfung, ob der Benutzer bereits einen Fortschritt hat
$stmt = $pdo->prepare('SELECT COUNT(*) FROM inventur_progress WHERE mitarbeiter_id = ?');
$stmt->execute([$mitarbeiter_id]);
$progressExists = $stmt->fetchColumn() > 0;

// Wenn keine Fortschritt vorhanden ist und keine Ebenenauswahl getroffen wurde, zeigen wir die Auswahlseite
if (!$progressExists) {
    $show_ebenen_auswahl = true;
} else {
    $show_ebenen_auswahl = false;
}


// Berechnung des Fortschritts, wenn ein Fortschritt existiert
if ($progressExists && !$show_ebenen_auswahl) {
    // Berechnung des Fortschritts
    $stmt = $pdo->prepare('SELECT COUNT(*) FROM inventur_progress WHERE mitarbeiter_id = ?');
    $stmt->execute([$mitarbeiter_id]);
    $total = $stmt->fetchColumn();

    $stmt = $pdo->prepare('SELECT COUNT(*) FROM inventur_progress WHERE mitarbeiter_id = ? AND completed IN (1,2)');
    $stmt->execute([$mitarbeiter_id]);
    $completed = $stmt->fetchColumn();

    $progressPercentage = ($total > 0) ? round(($completed / $total) * 100, 2) : 0;

    // Nächsten Lagerplatz abrufen, der noch nicht abgeschlossen ist
    if (!isset($currentLagerplatzId)) {
        $stmt = $pdo->prepare('
            SELECT lp.id, lp.name, lp.belegung
            FROM lagerplaetze lp
            JOIN inventur_progress ip ON lp.id = ip.lagerplatz_id
            WHERE ip.mitarbeiter_id = ? AND ip.completed = 0
            ORDER BY lp.id ASC
            LIMIT 1
        ');
        $stmt->execute([$mitarbeiter_id]);
        $currentLagerplatz = $stmt->fetch(PDO::FETCH_ASSOC);
    } else {
        // Lagerplatz mit der ID $currentLagerplatzId abrufen
        $stmt = $pdo->prepare('
            SELECT lp.id, lp.name, lp.belegung
            FROM lagerplaetze lp
            WHERE lp.id = ?
        ');
        $stmt->execute([$currentLagerplatzId]);
        $currentLagerplatz = $stmt->fetch(PDO::FETCH_ASSOC);
    }

    // Falls der Benutzer den letzten Lagerplatz bearbeitet hat und kein weiterer vorhanden ist
    // Überprüfen, ob es übersprungene Lagerplätze gibt, die noch bearbeitet werden müssen
    if (!$currentLagerplatz && !isset($message)) {
        $stmt = $pdo->prepare('
            SELECT lp.id, lp.name, lp.belegung
            FROM lagerplaetze lp
            JOIN inventur_progress ip ON lp.id = ip.lagerplatz_id
            WHERE ip.mitarbeiter_id = ? AND ip.completed = 2
            ORDER BY lp.id ASC
            LIMIT 1
        ');
        $stmt->execute([$mitarbeiter_id]);
        $currentLagerplatz = $stmt->fetch(PDO::FETCH_ASSOC);
    }
}
?>
<!DOCTYPE html>
<html lang="de">
<head>
    <meta charset="UTF-8">
    <title>Inventur</title>
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <!-- Bootstrap CSS und Icons -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <!-- Bootstrap Icons -->
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.10.5/font/bootstrap-icons.css">
    <!-- Eigenes CSS -->
    <style>
        body {
            background-color: #f2f5f7;
            font-family: 'Roboto', sans-serif;
            padding-bottom: 60px; /* Platz für die mobile Navigation */
        }
        /* Navbar Styling */
        .navbar {
            height: 86px;
            box-shadow: 0 4px 6px rgba(0, 0, 0, 0.1);
            transition: background-color 0.5s, box-shadow 0.5s;
        }

        .navbar-brand {
            font-weight: bold;
            font-size: 1.5rem;
            height: 66px;
        }

        .navbar-brand img {
            height: 100%; /* Höhe des Logos auf die Höhe der Navbar setzen */
            width: auto; /* Proportionen beibehalten */
            object-fit: contain; /* Falls nötig, das Logo anpassen */
        }
        .inventur-container {
            max-width: 600px;
            margin: 20px auto;
            text-align: center;
        }
        .lagerplatz-name {
            font-size: 1.8em;
            margin-bottom: 10px;
            font-weight: bold;
        }
        .expected-value {
            font-size: 2em;
            color: #007bff;
            margin-bottom: 20px;
        }
        .input-group {
            margin-bottom: 20px;
        }
        .btn-action {
            width: 100px;
            font-size: 1em;
        }
        /* Fortschrittsbalken */
        .progress {
            height: 20px;
            margin-bottom: 20px;
        }
        .progress-bar {
            font-size: 0.9em;
            line-height: 20px;
        }
        /* Mobile Optimierung */
        @media (max-width: 767px) {
            .inventur-container {
                margin: 10px;
            }
            .lagerplatz-name {
                font-size: 1.5em;
            }
            .expected-value {
                font-size: 1.8em;
            }
            .btn-action {
                width: 80px;
                font-size: 0.9em;
            }
            .navbar-brand {
                font-size: 1.2em;
            }
        }
        /* Mobile Bottom Navigation */
        .mobile-nav {
            display: none;
        }
        @media (max-width: 767px) {
            .mobile-nav {
                display: flex;
                position: fixed;
                bottom: 0;
                left: 0;
                right: 0;
                background-color: #fff;
                border-top: 1px solid #ccc;
                justify-content: space-around;
                padding: 5px 0;
                z-index: 1000;
            }
            .mobile-nav a {
                color: #000;
                text-decoration: none;
                font-size: 0.8em;
                text-align: center;
            }
            .mobile-nav a i {
                display: block;
                font-size: 1.4em;
            }
        }
        /* Tooltip-Stil */
        .tooltip-inner {
            max-width: 200px;
            padding: .25rem .5rem;
            color: #fff;
            text-align: center;
            background-color: #000;
            border-radius: .25rem;
        }
        /* Verbesserte Zusammenfassungstabelle */
        .inventur-summary table {
            width: 100%;
            overflow-x: auto;
        }
        /* Verbesserte Eingabeformulare */
        .inventur-entry .input-group input {
            font-size: 1.2em;
            padding: 10px;
        }
        .inventur-entry .btn {
            padding: 10px;
            font-size: 1em;
        }
        /* Bestätigungsdialog */
        .confirm-dialog {
            background-color: #fff;
            border: 1px solid #ccc;
            padding: 20px;
            border-radius: 8px;
            box-shadow: 0 4px 8px rgba(0,0,0,0.1);
            max-width: 500px;
            margin: 40px auto;
        }
        /* Verbesserte Ebenenauswahl */
        .ebenen-auswahl .form-check {
            display: inline-block;
            width: 45%;
            margin: 5px 2.5%;
        }
        .ebenen-auswahl .form-check-input {
            width: 1.5em;
            height: 1.5em;
        }
        .ebenen-auswahl .form-check-label {
            font-size: 1.2em;
            margin-left: 0.5em;
        }
    </style>
</head>
<body>

<!-- Navigation -->
<nav class="navbar navbar-expand-lg navbar-dark bg-dark d-none d-md-block">
  <div class="container-fluid">
    <a class="navbar-brand" href="index.php"><img src="img/logo.png"></a>
    <div class="collapse navbar-collapse justify-content-end">
       <ul class="navbar-nav">
         <li class="nav-item"><a class="nav-link" href="dashboard.php">Dashboard</a></li>
         <li class="nav-item"><a class="nav-link" href="aufgaben.php">Aufgaben</a></li>
         <li class="nav-item"><a class="nav-link" href="lagerplaetze.php">Lagerplätze</a></li>
         <li class="nav-item"><a class="nav-link" href="bericht.php">Berichte</a></li>
         <li class="nav-item"><a class="nav-link" href="settings.php">Einstellungen</a></li>
         <li class="nav-item"><a class="nav-link" href="logout.php">Abmelden</a></li>
       </ul>
    </div>
  </div>
</nav>

<!-- Mobile Bottom Navigation -->
<div class="mobile-nav d-md-none">
    <a href="dashboard.php">
        <i class="bi bi-house-fill"></i>
        Dashboard
    </a>
    <a href="aufgaben.php">
        <i class="bi bi-list-task"></i>
        Aufgaben
    </a>
    <a href="lagerplaetze.php">
        <i class="bi bi-box-seam"></i>
        Lagerplätze
    </a>
    <a href="bericht.php">
        <i class="bi bi-bar-chart-fill"></i>
        Berichte
    </a>
    <a href="settings.php">
        <i class="bi bi-gear-fill"></i>
        Einstellungen
    </a>
    <a href="logout.php">
        <i class="bi bi-box-arrow-right"></i>
        Abmelden
    </a>
</div>

<div class="container inventur-container">
    <h2 class="mb-4"><i class="bi bi-clipboard-check"></i> Inventur durchführen</h2>

    <!-- Fortschrittsbalken -->
    <div class="progress">
        <div class="progress-bar bg-success" role="progressbar" style="width: <?php echo htmlspecialchars($progressPercentage); ?>%;" aria-valuenow="<?php echo htmlspecialchars($progressPercentage); ?>" aria-valuemin="0" aria-valuemax="100">
            <?php echo htmlspecialchars($progressPercentage); ?>%
        </div>
    </div>

    <!-- Erfolgsmeldung -->
    <?php if (!empty($message) && $show_ebenen_auswahl): ?>
        <div class="alert alert-success text-center" role="alert">
            <i class="bi bi-check-circle-fill"></i> <?php echo htmlspecialchars($message); ?>
        </div>
    <?php endif; ?>


    <!-- Fehlermeldungen -->
    <?php if (!empty($errors)): ?>
        <div class="alert alert-danger text-center" role="alert">
            <i class="bi bi-exclamation-triangle-fill"></i> 
            <?php foreach ($errors as $error): ?>
                <p><?php echo htmlspecialchars($error); ?></p>
            <?php endforeach; ?>
        </div>
    <?php endif; ?>

    <?php if ($show_ebenen_auswahl): ?>
        <!-- Auswahlseite für Ebenen -->
        <div class="ebenen-auswahl">
            <?php if (!empty($message)): ?>
                <div class="alert alert-success text-center" role="alert">
                    <i class="bi bi-check-circle-fill"></i> <?php echo htmlspecialchars($message); ?>
                </div>
            <?php endif; ?>
            <h3 class="mb-3"><i class="bi bi-filter-square"></i> Wählen Sie die Bereiche aus, die Sie inventarisieren möchten:</h3>
            <form method="POST" action="inventur.php">
                <div class="mb-4">
                    <div class="form-check">
                        <input class="form-check-input" type="checkbox" value="Alles" id="bereichAlles" name="ebenen[]" checked>
                        <label class="form-check-label" for="bereichAlles">Alles</label>
                    </div>
                    <?php if (!empty($verfuegbare_ebenen)): ?>
                        <?php foreach ($verfuegbare_ebenen as $ebene): ?>
                            <div class="form-check">
                                <input 
                                    class="form-check-input" 
                                    type="checkbox" 
                                    value="<?php echo htmlspecialchars($ebene['kurzel']); ?>" 
                                    id="bereich<?php echo htmlspecialchars($ebene['kurzel']); ?>" 
                                    name="ebenen[]" 
                                    checked>
                                <label class="form-check-label" for="bereich<?php echo htmlspecialchars($ebene['kurzel']); ?>">
                                    <?php echo htmlspecialchars($ebene['bezeichnung']); ?>
                                </label>
                            </div>
                        <?php endforeach; ?>
                    <?php else: ?>
                        <p class="text-muted">Keine Ebenen verfügbar. Bitte konfigurieren Sie die Ebenen in den Einstellungen.</p>
                    <?php endif; ?>
                </div>
                <button type="submit" name="action" value="start" class="btn btn-primary"><i class="bi bi-play-circle-fill"></i> Starten</button>
            </form>
        </div>

        <!-- JavaScript für verbesserte Ebenenauswahl -->
        <script>
            document.addEventListener('DOMContentLoaded', function () {
                const allesCheckbox = document.getElementById('bereichAlles');
                const ebenenCheckboxes = <?php echo json_encode($verfuegbare_ebenen); ?>.map(ebene => document.getElementById('bereich' + ebene.kurzel));

                allesCheckbox.addEventListener('change', function () {
                    const checked = this.checked;
                    ebenenCheckboxes.forEach(checkbox => {
                        checkbox.checked = checked;
                        checkbox.disabled = checked; // Deaktiviert die einzelnen Checkboxen, wenn "Alles" ausgewählt ist
                    });
                });

                ebenenCheckboxes.forEach(checkbox => {
                    checkbox.addEventListener('change', function () {
                        const allChecked = ebenenCheckboxes.every(cb => cb.checked);
                        if (!this.checked) {
                            allesCheckbox.checked = false;
                            ebenenCheckboxes.forEach(cb => cb.disabled = false); // Aktiviert die Checkboxen, wenn "Alles" deaktiviert ist
                        } else if (allChecked) {
                            allesCheckbox.checked = true;
                            ebenenCheckboxes.forEach(cb => cb.disabled = true);
                        }
                    });
                });
            });

        </script>
    <?php elseif ($progressExists && !$show_ebenen_auswahl): ?>
        <?php if (!$currentLagerplatz && empty($message)): ?>
            <!-- Zusammenfassungsseite -->
            <div class="inventur-summary">
                <h3 class="mb-4"><i class="bi bi-list-check"></i> Zusammenfassung</h3>
                <div class="table-responsive">
                    <table class="table table-striped table-bordered">
                        <thead class="table-dark">
                            <tr>
                                <th>Lagerplatz</th>
                                <th>Soll</th>
                                <th>Ist</th>
                                <th>Status</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php
                            // Hole alle Einträge
                            $stmt = $pdo->prepare('
                                SELECT lp.name, lp.belegung AS soll, ip.belegung AS ist, ip.completed
                                FROM lagerplaetze lp
                                JOIN inventur_progress ip ON lp.id = ip.lagerplatz_id
                                WHERE ip.mitarbeiter_id = ?
                            ');
                            $stmt->execute([$mitarbeiter_id]);
                            $inventurData = $stmt->fetchAll(PDO::FETCH_ASSOC);

                            foreach ($inventurData as $data):
                                if ($data['completed'] == 1) {
                                    $status = '<span class="badge bg-success">Abgeschlossen</span>';
                                } elseif ($data['completed'] == 2) {
                                    $status = '<span class="badge bg-warning text-dark">Übersprungen</span>';
                                } else {
                                    $status = '<span class="badge bg-secondary">Offen</span>';
                                }
                            ?>
                            <tr>
                                <td><?php echo htmlspecialchars($data['name']); ?></td>
                                <td><?php echo htmlspecialchars($data['soll']); ?></td>
                                <td><?php echo htmlspecialchars($data['ist'] ?? 'Übersprungen'); ?></td>
                                <td><?php echo $status; ?></td>
                            </tr>
                            <?php endforeach; ?>
                        </tbody>
                    </table>
                </div>
                <form method="POST" action="inventur.php">
                    <button type="submit" name="action" value="updateDatabase" class="btn btn-success btn-lg mt-3">
                        <i class="bi bi-save2"></i> Inventur abschließen
                    </button>
                </form>
            </div>
        <?php else: ?>
            <?php if ($overCapacity): ?>
                <!-- Bestätigungsseite bei Überkapazität -->
                <div class="confirm-dialog">
                    <div class="alert alert-warning">
                        <i class="bi bi-exclamation-circle"></i> Die eingegebene Belegung (<strong><?php echo htmlspecialchars($belegung); ?></strong>) übersteigt die aktuelle Kapazität (<strong><?php echo htmlspecialchars($kapazitaet); ?></strong>) des Lagerplatzes. Möchten Sie die Kapazität auf <strong><?php echo htmlspecialchars($belegung); ?></strong> erhöhen?
                    </div>
                    <form method="POST" action="inventur.php">
                        <input type="hidden" name="lagerplatz_id" value="<?php echo htmlspecialchars($currentLagerplatz['id']); ?>">
                        <input type="hidden" name="belegung" value="<?php echo htmlspecialchars($belegung); ?>">
                        <input type="hidden" name="confirm_over_capacity" value="1">
                        <div class="d-flex justify-content-between flex-wrap">
                            <button type="submit" name="action" value="cancel_over_capacity" class="btn btn-danger btn-lg mb-2" data-bs-toggle="tooltip" data-bs-placement="top" title="Überkapazität nicht bestätigen">
                                <i class="bi bi-x-circle"></i> Abbrechen
                            </button>
                            <button type="submit" name="action" value="weiter" class="btn btn-success btn-lg mb-2" data-bs-toggle="tooltip" data-bs-placement="top" title="Überkapazität bestätigen">
                                <i class="bi bi-check-circle"></i> Bestätigen
                            </button>
                        </div>
                    </form>
                </div>
            <?php else: ?>
                <!-- Eingabeseite für den aktuellen Lagerplatz -->
                <div class="inventur-entry">
                    <h3 class="mb-3"><i class="bi bi-warehouse"></i> Lagerplatz: <?php echo htmlspecialchars($currentLagerplatz['name']); ?></h3>
                    <p class="expected-value"><i class="bi bi-boxes"></i> Soll-Bestand: <?php echo htmlspecialchars($currentLagerplatz['belegung']); ?></p>
                    <form method="POST" action="inventur.php">
                        <input type="hidden" name="lagerplatz_id" value="<?php echo htmlspecialchars($currentLagerplatz['id']); ?>">
                        <div class="input-group mb-4">
                            <input type="number" name="belegung" class="form-control form-control-lg" placeholder="Ist-Bestand eingeben" value="<?php echo $retainBelegungValue && isset($belegung) ? htmlspecialchars($belegung) : ''; ?>" autofocus required>
                            <span class="input-group-text"><i class="bi bi-pencil-fill"></i></span>
                        </div>
                        <div class="d-flex justify-content-between flex-wrap">
                            <button type="submit" name="action" value="zurueck" formnovalidate class="btn btn-warning btn-action mb-2" data-bs-toggle="tooltip" data-bs-placement="top" title="Vorherigen Lagerplatz bearbeiten">
                                <i class="bi bi-arrow-left-circle"></i> Zurück
                            </button>
                            <button type="submit" name="action" value="ueberspringen" formnovalidate class="btn btn-secondary btn-action mb-2" data-bs-toggle="tooltip" data-bs-placement="top" title="Diesen Lagerplatz später bearbeiten">
                                <i class="bi bi-arrow-right-circle"></i> Überspringen
                            </button>
                            <button type="submit" name="action" value="weiter" class="btn btn-primary btn-action mb-2" data-bs-toggle="tooltip" data-bs-placement="top" title="Eingabe speichern und fortfahren">
                                <i class="bi bi-check-circle"></i> Weiter
                            </button>
                        </div>
                        <div class="mt-3">
                            <button type="submit" name="action" value="abbrechen" formnovalidate class="btn btn-danger btn-lg">
                                <i class="bi bi-x-circle"></i> Inventur abbrechen
                            </button>
                        </div>
                    </form>
                </div>
            <?php endif; ?>
        <?php endif; ?>
    <?php endif; ?>
</div>

<!-- Bootstrap JS und Abhängigkeiten -->
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>

<!-- JavaScript zur Initialisierung der Tooltips und zur Behandlung der Enter-Taste -->
<script>
    document.addEventListener('DOMContentLoaded', function() {
        // Tooltips initialisieren
        var tooltipTriggerList = [].slice.call(document.querySelectorAll('[data-bs-toggle="tooltip"]'));
        tooltipTriggerList.map(function (tooltipTriggerEl) {
            return new bootstrap.Tooltip(tooltipTriggerEl);
        });

        // Enter-Taste zum Weiter-Button zuordnen (nur in der Eingabeseite)
        const belegungInput = document.querySelector('input[name="belegung"]');
        const weiterButton = document.querySelector('button[name="action"][value="weiter"]');

        if (belegungInput && weiterButton) {
            belegungInput.addEventListener('keypress', function(event) {
                if (event.key === 'Enter') {
                    event.preventDefault();  // Verhindert das Standardformularverhalten
                    weiterButton.click();     // Klick auf den "Weiter"-Button simulieren
                }
            });
        }
    });
</script>

</body>
</html>
