<?php
session_start();
include 'license_check.php';
include 'db_connect.php';

// Überprüfung, ob der Benutzer angemeldet ist
if (!isset($_SESSION['user_id'])) {
    header('Location: login.php');
    exit();
}

$isAdmin = isset($_SESSION['rolle']) && strtolower($_SESSION['rolle']) === 'admin';

// Nachrichtenspeicher
$message = "";

// Lizenzinformationen aus der settings-Tabelle abrufen
$stmt = $pdo->prepare('SELECT value FROM settings WHERE key_name = "license_data"');
$stmt->execute();
$licenseDataJson = $stmt->fetchColumn();
$licenseData = $licenseDataJson ? json_decode($licenseDataJson, true) : null;

// Laden der aktuellen Einstellungen aus der Datenbank
$stmt = $pdo->prepare('SELECT * FROM settings WHERE key_name = "lagerplatz_ebenen" LIMIT 1');
$stmt->execute();
$setting = $stmt->fetch();
$lagerplatz_ebenen = $setting ? json_decode($setting['value'], true) : [];

// Laden der Produkttyp-Zuordnung
$stmt = $pdo->prepare('SELECT * FROM settings WHERE key_name = "lagerplatz_mapping" LIMIT 1');
$stmt->execute();
$mappingSetting = $stmt->fetch();
$mapping = $mappingSetting ? json_decode($mappingSetting['value'], true) : [];

// Verarbeitung der Formulareingaben
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    if (isset($_POST['ebenen_kurzel']) && isset($_POST['ebenen_bezeichnung'])) {
        $new_ebenen = [];
        foreach ($_POST['ebenen_kurzel'] as $index => $kurzel) {
            $kurzel = trim($kurzel);
            $bezeichnung = trim($_POST['ebenen_bezeichnung'][$index]);
            if (!empty($kurzel) && !empty($bezeichnung)) {
                $new_ebenen[] = ["kurzel" => $kurzel, "bezeichnung" => $bezeichnung];
            }
        }
        $new_ebenen_json = json_encode($new_ebenen);

        if ($setting) {
            // Bestehende Einstellung aktualisieren
            $stmt = $pdo->prepare('UPDATE settings SET value = :value, updated_at = NOW() WHERE key_name = "lagerplatz_ebenen"');
        } else {
            // Neue Einstellung einfügen
            $stmt = $pdo->prepare('INSERT INTO settings (key_name, value, description) VALUES ("lagerplatz_ebenen", :value, "Lagerplatz-Ebenen")');
        }

        $stmt->execute(['value' => $new_ebenen_json]);
        $message = "Die Lagerplatz-Ebenen wurden erfolgreich aktualisiert.";
        $lagerplatz_ebenen = $new_ebenen;
    }

    if (isset($_POST['mapping_keys']) && isset($_POST['mapping_values'])) {
        $new_mapping = [];
        foreach ($_POST['mapping_keys'] as $index => $key) {
            $key = trim($key);
            $value = trim($_POST['mapping_values'][$index]);
            if (!empty($key) && !empty($value)) {
                $new_mapping[$key] = $value;
            }
        }
        $new_mapping_json = json_encode($new_mapping);

        if ($mappingSetting) {
            // Bestehende Einstellung aktualisieren
            $stmt = $pdo->prepare('UPDATE settings SET value = :value, updated_at = NOW() WHERE key_name = "lagerplatz_mapping"');
        } else {
            // Neue Einstellung einfügen
            $stmt = $pdo->prepare('INSERT INTO settings (key_name, value, description) VALUES ("lagerplatz_mapping", :value, "Zuordnung Produkttypen zu Lagerplatz-Ebenen")');
        }

        $stmt->execute(['value' => $new_mapping_json]);
        $message .= "<br>Die Produkttypen-Zuordnung wurde erfolgreich aktualisiert.";
        $mapping = $new_mapping;
    }
}
?>

<!DOCTYPE html>
<html lang="de">
<head>
    <meta charset="UTF-8">
    <title>Einstellungen - Lagerplatz</title>
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.10.5/font/bootstrap-icons.css">
    <style>
        body {
            background-color: #f9f9f9;
            font-family: Arial, sans-serif;
        }
        .settings-container {
            max-width: 700px;
            margin: 20px auto;
        }
        .settings-container h2 {
            text-align: center;
            margin-bottom: 20px;
        }
        /* Navbar Styling */
        .navbar {
            height: 86px;
            box-shadow: 0 4px 6px rgba(0, 0, 0, 0.1);
            transition: background-color 0.5s, box-shadow 0.5s;
        }

        .navbar-brand {
            font-weight: bold;
            font-size: 1.5rem;
            height: 66px;
        }

        .navbar-brand img {
            height: 100%; /* Höhe des Logos auf die Höhe der Navbar setzen */
            width: auto; /* Proportionen beibehalten */
            object-fit: contain; /* Falls nötig, das Logo anpassen */
        }
        .form-control, .btn {
            border-radius: 8px;
        }
        /* Tooltip-Stil */
        .tooltip-inner {
            max-width: 200px;
            padding: .25rem .5rem;
            color: #fff;
            text-align: center;
            background-color: #000;
            border-radius: .25rem;
        }
        .admin-btn {
            display: block;
            margin: 20px auto;
            padding: 10px 20px;
            border-radius: 8px;
            font-size: 1rem;
            text-align: center;
            background-color: #3498db;
            color: white;
            border: none;
            text-decoration: none;
            transition: background-color 0.3s ease;
        }
        .admin-btn:hover {
            background-color: #2980b9;
            text-decoration: none;
        }
        /* Mobile Bottom Navigation */
        .mobile-nav {
            display: none;
        }
        @media (max-width: 767.98px) {
            .mobile-nav {
                display: flex;
                position: fixed;
                bottom: 0;
                left: 0;
                right: 0;
                background-color: #343a40;
                border-top: 1px solid #495057;
                justify-content: space-around;
                padding: 10px 0;
                z-index: 1000;
            }
            .mobile-nav a {
                color: #adb5bd;
                text-decoration: none;
                font-size: 0.85em;
                text-align: center;
                flex: 1;
                display: flex;
                flex-direction: column;
                align-items: center;
            }
            .mobile-nav a i {
                font-size: 1.5em;
                margin-bottom: 2px;
            }
            .mobile-nav a.active {
                color: #ffffff;
            }
        }
    </style>
</head>
<body>

<!-- Navigation für Desktop -->
<nav class="navbar navbar-expand-lg navbar-dark bg-dark d-none d-md-block">
  <div class="container-fluid">
    <a class="navbar-brand" href="index.php"><img src="img/logo.png"></a>
    <div class="collapse navbar-collapse justify-content-end">
       <ul class="navbar-nav">
         <li class="nav-item">
             <a class="nav-link <?php echo (basename($_SERVER['PHP_SELF']) == 'dashboard.php') ? 'active' : ''; ?>" href="dashboard.php">
                 <i class="bi bi-speedometer2 me-1"></i>Dashboard
             </a>
         </li>
         <li class="nav-item">
             <a class="nav-link <?php echo (basename($_SERVER['PHP_SELF']) == 'aufgaben.php') ? 'active' : ''; ?>" href="aufgaben.php">
                 <i class="bi bi-list-task me-1"></i>Aufgaben
             </a>
         </li>
         <li class="nav-item">
             <a class="nav-link <?php echo (basename($_SERVER['PHP_SELF']) == 'lagerplaetze.php') ? 'active' : ''; ?>" href="lagerplaetze.php">
                 <i class="bi bi-box-seam me-1"></i>Lagerplätze
             </a>
         </li>
         <li class="nav-item">
             <a class="nav-link" href="bericht.php">
                 <i class="bi bi-bar-chart-fill me-1"></i>Berichte
             </a>
         </li>
         <li class="nav-item">
             <a class="nav-link <?php echo (basename($_SERVER['PHP_SELF']) == 'settings.php') ? 'active' : ''; ?>" href="settings.php">
                 <i class="bi bi-gear-fill"></i>Einstellungen
             </a>
         </li>
         <li class="nav-item">
             <a class="nav-link" href="logout.php">
                 <i class="bi bi-box-arrow-right me-1"></i>Abmelden
             </a>
         </li>
       </ul>
    </div>
  </div>
</nav>

<!-- Mobile Bottom Navigation -->
<div class="mobile-nav d-md-none">
    <a class="<?php echo (basename($_SERVER['PHP_SELF']) == 'dashboard.php') ? 'active' : ''; ?>" href="dashboard.php">
        <i class="bi bi-speedometer2"></i>
        Dashboard
    </a>
    <a class="<?php echo (basename($_SERVER['PHP_SELF']) == 'aufgaben.php') ? 'active' : ''; ?>" href="aufgaben.php">
        <i class="bi bi-list-task"></i>
        Aufgaben
    </a>
    <a class="<?php echo (basename($_SERVER['PHP_SELF']) == 'lagerplaetze.php') ? 'active' : ''; ?>" href="lagerplaetze.php">
        <i class="bi bi-box-seam"></i>
        Lagerplätze
    </a>
    <a class="<?php echo (basename($_SERVER['PHP_SELF']) == 'bericht.php') ? 'active' : ''; ?>" href="bericht.php">
        <i class="bi bi-bar-chart-fill"></i>
        Berichte
    </a>
    <a class="<?php echo (basename($_SERVER['PHP_SELF']) == 'settings.php') ? 'active' : ''; ?>" href="settings.php">
        <i class="bi bi-gear-fill"></i>
        Einstellungen
    </a>
    <a href="logout.php">
        <i class="bi bi-box-arrow-right"></i>
        Abmelden
    </a>
</div>

<div class="settings-container">
    <h2><i class="bi bi-gear-fill"></i> Einstellungen</h2>
    <?php if ($isAdmin): ?>
        <!-- Admin-Buttons -->
        <a href="users.php" class="admin-btn"><i class="bi bi-people-fill"></i> Benutzerverwaltung</a>
        <a href="update.php" class="admin-btn"><i class="bi bi-arrow-repeat"></i> System-Update</a>
    <?php endif; ?>
    <?php if (!empty($message)): ?>
        <div class="alert alert-success"><?php echo nl2br(htmlspecialchars($message)); ?></div>
    <?php endif; ?>

    <!-- Lizenzstatus anzeigen -->
    <?php if ($licenseData): ?>
        <div class="alert alert-info">
            <h5>Lizenzstatus</h5>
            <p>Kunde: <strong><?php echo htmlspecialchars($licenseData['customer_name']); ?></strong></p>
            <p>Status: <strong><?php echo htmlspecialchars($licenseData['status']); ?></strong></p>
            <p>Gültig von: <strong><?php echo htmlspecialchars($licenseData['start_date']); ?></strong></p>
            <p>Gültig bis: <strong><?php echo htmlspecialchars($licenseData['end_date']); ?></strong></p>
            <p>Verbleibende Tage: <strong><?php echo htmlspecialchars($licenseData['remaining_days']); ?> Tage</strong></p>
        </div>
    <?php else: ?>
        <div class="alert alert-warning">
            <p>Keine Lizenzinformationen verfügbar.</p>
        </div>
    <?php endif; ?>


    <!-- Lagerplatz-Ebenen -->
    <h4>Lagerplatz-Ebenen verwalten</h4>
    <form method="POST">
        <div id="ebenen-list">
            <?php foreach ($lagerplatz_ebenen as $ebene): ?>
                <div class="input-group mb-3">
                    <input type="text" name="ebenen_kurzel[]" class="form-control" value="<?php echo htmlspecialchars($ebene['kurzel']); ?>" placeholder="Kürzel (z. B. EG)" required>
                    <input type="text" name="ebenen_bezeichnung[]" class="form-control" value="<?php echo htmlspecialchars($ebene['bezeichnung']); ?>" placeholder="Bezeichnung (z. B. Erdgeschoss)" required>
                    <button type="button" class="btn btn-danger remove-ebene">Entfernen</button>
                </div>
            <?php endforeach; ?>
        </div>
        <button type="button" id="add-ebene" class="btn btn-success mb-3">+ Ebene hinzufügen</button>
        <button type="submit" class="btn btn-primary w-100">Speichern</button>
    </form>

    <!-- Produkttypen-Zuordnung -->
    <h4 class="mt-5">Produkttypen-Zuordnung</h4>
    <form method="POST">
        <div id="mapping-list">
            <?php foreach ($mapping as $key => $value): ?>
                <div class="input-group mb-3">
                    <input type="text" name="mapping_keys[]" class="form-control" value="<?php echo htmlspecialchars($key); ?>" placeholder="Produkttyp" required>
                    <input type="text" name="mapping_values[]" class="form-control" value="<?php echo htmlspecialchars($value); ?>" placeholder="Ebene" required>
                    <button type="button" class="btn btn-danger remove-mapping">Entfernen</button>
                </div>
            <?php endforeach; ?>
        </div>
        <button type="button" id="add-mapping" class="btn btn-success mb-3">+ Zuordnung hinzufügen</button>
        <button type="submit" class="btn btn-primary w-100">Speichern</button>
    </form>
</div>

<script>
document.addEventListener('DOMContentLoaded', function () {
    const ebeneList = document.getElementById('ebenen-list');
    const addEbeneButton = document.getElementById('add-ebene');
    const mappingList = document.getElementById('mapping-list');
    const addMappingButton = document.getElementById('add-mapping');

    // Funktion zum Hinzufügen einer neuen Ebene
    addEbeneButton.addEventListener('click', function () {
        const div = document.createElement('div');
        div.classList.add('input-group', 'mb-3');
        div.innerHTML = `
            <input type="text" name="ebenen_kurzel[]" class="form-control" placeholder="Kürzel (z. B. EG)" required>
            <input type="text" name="ebenen_bezeichnung[]" class="form-control" placeholder="Bezeichnung (z. B. Erdgeschoss)" required>
            <button type="button" class="btn btn-danger remove-ebene">Entfernen</button>
        `;
        ebeneList.appendChild(div);
    });

    // Funktion zum Hinzufügen einer neuen Zuordnung
    addMappingButton.addEventListener('click', function () {
        const div = document.createElement('div');
        div.classList.add('input-group', 'mb-3');
        div.innerHTML = `
            <input type="text" name="mapping_keys[]" class="form-control" placeholder="Produkttyp" required>
            <input type="text" name="mapping_values[]" class="form-control" placeholder="Ebene" required>
            <button type="button" class="btn btn-danger remove-mapping">Entfernen</button>
        `;
        mappingList.appendChild(div);
    });

    // Delegierter Event-Listener für die "Entfernen"-Buttons
    document.addEventListener('click', function (e) {
        if (e.target.classList.contains('remove-ebene')) {
            e.target.closest('.input-group').remove();
        }
        if (e.target.classList.contains('remove-mapping')) {
            e.target.closest('.input-group').remove();
        }
    });
});

</script>

<!-- Bootstrap JS -->
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>
